@@ -1,5 +1,5 @@
 /* pinentry.c - The PIN entry support library
-   Copyright (C) 2002, 2003, 2007, 2008, 2010 g10 Code GmbH
+   Copyright (C) 2002, 2003, 2007, 2008, 2010, 2015 g10 Code GmbH
 
    This file is part of PINENTRY.
 
@@ -26,7 +26,6 @@
 #endif
 #include <stdlib.h>
 #include <string.h>
-#include <getopt.h>
 #include <unistd.h>
 #ifndef HAVE_W32CE_SYSTEM
 # include <locale.h>
@@ -46,7 +45,9 @@
 #include "assuan.h"
 #include "memory.h"
 #include "secmem-util.h"
+#include "argparse.h"
 #include "pinentry.h"
+#include "password-cache.h"
 
 #ifdef HAVE_W32CE_SYSTEM
 #define getpid() GetCurrentProcessId ()
@@ -67,6 +68,7 @@ struct pinentry pinentry =
     NULL,	/* Cancel button.  */
     NULL,	/* PIN.  */
     2048,	/* PIN length.  */
+    0,          /* pin_from_cache.  */
     0,		/* Display.  */
     0,		/* TTY name.  */
     0,		/* TTY type.  */
@@ -84,6 +86,7 @@ struct pinentry pinentry =
     0,		/* Canceled.  */
     0,		/* Close button flag.  */
     0,          /* Locale error flag. */
+    0,          /* Specific error flag. */
     0,          /* One-button flag.  */
     NULL,       /* Repeat passphrase flag.  */
     NULL,       /* Repeat error string.  */
@@ -98,13 +101,18 @@ struct pinentry pinentry =
     NULL,        /* default_ok  */
     NULL,        /* default_cancel  */
     NULL,        /* default_prompt  */
+    NULL,        /* default_pwmngr  */
+    0,           /* allow_external_password_cache.  */
+    0,           /* tried_password_cached.  */
+    NULL,        /* keyinfo  */
+    0,           /* may_cache_password. */
     NULL         /* Assuan context.  */
   };
 
 
 #if defined FALLBACK_CURSES || defined PINENTRY_CURSES || defined PINENTRY_GTK
 char *
-pinentry_utf8_to_local (char *lc_ctype, char *text)
+pinentry_utf8_to_local (const char *lc_ctype, const char *text)
 {
   iconv_t cd;
   const char *input = text;
@@ -408,26 +416,46 @@ pinentry_have_display (int argc, char **argv)
 
 
 
-static void
-usage (void)
+/* Print usage information and and provide strings for help. */
+static const char *
+my_strusage( int level )
 {
-  fprintf (stdout, "Usage: %s [OPTION]...\n"
-"Ask securely for a secret and print it to stdout.\n"
-"\n"
-"      --display DISPLAY Set the X display\n"
-"      --ttyname PATH    Set the tty terminal node name\n"
-"      --ttytype NAME    Set the tty terminal type\n"
-"      --lc-ctype        Set the tty LC_CTYPE value\n"
-"      --lc-messages     Set the tty LC_MESSAGES value\n"
-"      --timeout SECS    Timeout waiting for input after this many seconds\n"
-#ifdef ENABLE_ENHANCED
-"  -e, --enhanced        Ask for timeout and insurance, too\n"
-#endif
-"  -g, --no-global-grab  Grab keyboard only while window is focused\n"
-"      --parent-wid      Parent window ID (for positioning)\n"
-"  -d, --debug           Turn on debugging output\n"
-"  -h, --help            Display this help and exit\n"
-"      --version         Output version information and exit\n", this_pgmname);
+  const char *p;
+
+  switch (level)
+    {
+    case 11: p = this_pgmname; break;
+    case 12: p = "pinentry"; break;
+    case 13: p = PACKAGE_VERSION; break;
+    case 14: p = "Copyright (C) 2015 g10 Code GmbH"; break;
+    case 19: p = "Please report bugs to <" PACKAGE_BUGREPORT ">.\n"; break;
+    case 1:
+    case 40:
+      {
+        static char *str;
+
+        if (!str)
+          {
+            size_t n = 50 + strlen (this_pgmname);
+            str = malloc (n);
+            if (str)
+              snprintf (str, n, "Usage: %s [options] (-h for help)",
+                        this_pgmname);
+          }
+        p = str;
+      }
+      break;
+    case 41:
+      p = "Ask securely for a secret and print it to stdout.";
+      break;
+
+    case 42:
+      p = "1"; /* Flag print 40 as part of 41. */
+      break;
+
+    default: p = NULL; break;
+    }
+  return p;
 }
 
 
@@ -481,40 +509,37 @@ parse_color (char *arg, pinentry_color_t *color_p, int *bright_p)
   return new_arg;
 }
 
-/* Parse the command line options.  Returns 1 if user should print
-   version and exit.  Can exit the program if only help output is
-   requested.  */
-int
+/* Parse the command line options.  May exit the program if only help
+   or version output is requested.  */
+void
 pinentry_parse_opts (int argc, char *argv[])
 {
-  int opt;
-  int opt_help = 0;
-  int opt_version = 0;
-  struct option opts[] =
-    {{ "debug", no_argument,             0, 'd' },
-     { "display", required_argument,     0, 'D' },
-     { "ttyname", required_argument,     0, 'T' },
-     { "ttytype", required_argument,     0, 'N' },
-     { "lc-ctype", required_argument,    0, 'C' },
-     { "lc-messages", required_argument, 0, 'M' },
+  static ARGPARSE_OPTS opts[] = {
+    ARGPARSE_s_n('d', "debug",    "Turn on debugging output"),
+    ARGPARSE_s_s('D', "display",  "|DISPLAY|Set the X display"),
+    ARGPARSE_s_s('T', "ttyname",  "|FILE|Set the tty terminal node name"),
+    ARGPARSE_s_s('N', "ttytype",  "|NAME|Set the tty terminal type"),
+    ARGPARSE_s_s('C', "lc-ctype", "|STRING|Set the tty LC_CTYPE value"),
+    ARGPARSE_s_s('M', "lc-messages", "|STRING|Set the tty LC_MESSAGES value"),
 #ifdef ENABLE_ENHANCED
-     { "enhanced", no_argument,          0, 'e' },
+    ARGPARSE_s_n('e', "enhanced", "Ask for timeout and insurance, too"),
 #endif
-     { "no-global-grab", no_argument,    0, 'g' },
-     { "parent-wid", required_argument,  0, 'W' },
-     { "colors", required_argument,	 0, 'c' },
-     { "help", no_argument,              0, 'h' },
-     { "version", no_argument, &opt_version, 1 },
-     { "timeout", required_argument, 0, 'o' },
-     { NULL, 0, NULL, 0 }};
+    ARGPARSE_s_i('o', "timeout",
+                 "|SECS|Timeout waiting for input after this many seconds"),
+    ARGPARSE_s_n('g', "no-global-grab",
+                 "Grab keyboard only while window is focused"),
+    ARGPARSE_s_u('W', "parent-wid", "Parent window ID (for positioning)"),
+    ARGPARSE_s_s('c', "colors", "|STRING|Set custom colors for ncurses"),
+    ARGPARSE_end()
+  };
+  ARGPARSE_ARGS pargs = { &argc, &argv, 0 };
 
-  while ((opt = getopt_long (argc, argv, "degh", opts, NULL)) != -1)
+  set_strusage (my_strusage);
+
+  while (arg_parse  (&pargs, opts))
     {
-      switch (opt)
+      switch (pargs.r_opt)
         {
-        case 0:
-        case '?':
-          break;
         case 'd':
           pinentry.debug = 1;
           break;
@@ -526,14 +551,11 @@ pinentry_parse_opts (int argc, char *argv[])
         case 'g':
           pinentry.grab = 0;
           break;
-        case 'h':
-          opt_help = 1;
-          break;
 
 	case 'D':
           /* Note, this is currently not used because the GUI engine
              has already been initialized when parsing these options. */
-	  pinentry.display = strdup (optarg);
+	  pinentry.display = strdup (pargs.r.ret_str);
 	  if (!pinentry.display)
 	    {
 #ifndef HAVE_W32CE_SYSTEM
@@ -543,7 +565,7 @@ pinentry_parse_opts (int argc, char *argv[])
 	    }
 	  break;
 	case 'T':
-	  pinentry.ttyname = strdup (optarg);
+	  pinentry.ttyname = strdup (pargs.r.ret_str);
 	  if (!pinentry.ttyname)
 	    {
 #ifndef HAVE_W32CE_SYSTEM
@@ -553,7 +575,7 @@ pinentry_parse_opts (int argc, char *argv[])
 	    }
 	  break;
 	case 'N':
-	  pinentry.ttytype = strdup (optarg);
+	  pinentry.ttytype = strdup (pargs.r.ret_str);
 	  if (!pinentry.ttytype)
 	    {
 #ifndef HAVE_W32CE_SYSTEM
@@ -563,7 +585,7 @@ pinentry_parse_opts (int argc, char *argv[])
 	    }
 	  break;
 	case 'C':
-	  pinentry.lc_ctype = strdup (optarg);
+	  pinentry.lc_ctype = strdup (pargs.r.ret_str);
 	  if (!pinentry.lc_ctype)
 	    {
 #ifndef HAVE_W32CE_SYSTEM
@@ -573,7 +595,7 @@ pinentry_parse_opts (int argc, char *argv[])
 	    }
 	  break;
 	case 'M':
-	  pinentry.lc_messages = strdup (optarg);
+	  pinentry.lc_messages = strdup (pargs.r.ret_str);
 	  if (!pinentry.lc_messages)
 	    {
 #ifndef HAVE_W32CE_SYSTEM
@@ -583,34 +605,30 @@ pinentry_parse_opts (int argc, char *argv[])
 	    }
 	  break;
 	case 'W':
-	  pinentry.parent_wid = atoi (optarg);
-	  /* FIXME: Add some error handling.  Use strtol.  */
+	  pinentry.parent_wid = pargs.r.ret_ulong;
 	  break;
 
 	case 'c':
-	  optarg = parse_color (optarg, &pinentry.color_fg,
-				&pinentry.color_fg_bright);
-	  optarg = parse_color (optarg, &pinentry.color_bg, NULL);
-	  optarg = parse_color (optarg, &pinentry.color_so,
-				&pinentry.color_so_bright);
+          {
+            char *tmpstr = pargs.r.ret_str;
+
+            tmpstr = parse_color (tmpstr, &pinentry.color_fg,
+                                  &pinentry.color_fg_bright);
+            tmpstr = parse_color (tmpstr, &pinentry.color_bg, NULL);
+            tmpstr = parse_color (tmpstr, &pinentry.color_so,
+                                  &pinentry.color_so_bright);
+          }
 	  break;
 
 	case 'o':
-	  pinentry.timeout = atoi(optarg);
+	  pinentry.timeout = pargs.r.ret_int;
 	  break;
+
         default:
-          fprintf (stderr, "%s: oops: option not handled\n", this_pgmname);
+          pargs.err = ARGPARSE_PRINT_WARNING;
 	  break;
         }
     }
-  if (opt_version)
-    return 1;
-  if (opt_help)
-    {
-      usage ();
-      exit (EXIT_SUCCESS);
-    }
-  return 0;
 }
 
 
@@ -701,6 +719,17 @@ option_handler (ASSUAN_CONTEXT ctx, const char *key, const char *value)
       if (!pinentry.default_prompt)
 	return ASSUAN_Out_Of_Core;
     }
+  else if (!strcmp (key, "default-pwmngr"))
+    {
+      pinentry.default_pwmngr = strdup (value);
+      if (!pinentry.default_pwmngr)
+	return ASSUAN_Out_Of_Core;
+    }
+  else if (!strcmp (key, "allow-external-password-cache") && !*value)
+    {
+      pinentry.allow_external_password_cache = 1;
+      pinentry.tried_password_cache = 0;
+    }
   else
     return ASSUAN_Invalid_Option;
   return 0;
@@ -761,6 +790,25 @@ cmd_setprompt (ASSUAN_CONTEXT ctx, char *line)
 }
 
 
+/* The data provided at LINE may be used by pinentry implementations
+   to identify a key for caching strategies of its own.  The empty
+   string and --clear mean that the key does not have a stable
+   identifier.  */
+static int
+cmd_setkeyinfo (ASSUAN_CONTEXT ctx, char *line)
+{
+  if (pinentry.keyinfo)
+    free (pinentry.keyinfo);
+
+  if (*line && strcmp(line, "--clear") != 0)
+    pinentry.keyinfo = strdup (line);
+  else
+    pinentry.keyinfo = NULL;
+
+  return 0;
+}
+
+
 static int
 cmd_setrepeat (ASSUAN_CONTEXT ctx, char *line)
 {
@@ -933,16 +981,64 @@ cmd_getpin (ASSUAN_CONTEXT ctx, char *line)
 {
   int result;
   int set_prompt = 0;
+  int just_read_password_from_cache = 0;
 
   pinentry.pin = secmem_malloc (pinentry.pin_len);
   if (!pinentry.pin)
     return ASSUAN_Out_Of_Core;
+
+  /* Try reading from the password cache.  */
+  if (/* If repeat passphrase is set, then we don't want to read from
+	 the cache.  */
+      ! pinentry.repeat_passphrase
+      /* Are we allowed to read from the cache?  */
+      && pinentry.allow_external_password_cache
+      && pinentry.keyinfo
+      /* Only read from the cache if we haven't already tried it.  */
+      && ! pinentry.tried_password_cache)
+    {
+      char *password;
+
+      pinentry.tried_password_cache = 1;
+
+      password = password_cache_lookup (pinentry.keyinfo);
+      if (password)
+	/* There is a cached password.  Try it.  */
+	{
+	  int len = strlen(password) + 1;
+	  if (len > pinentry.pin_len)
+	    len = pinentry.pin_len;
+
+	  memcpy (pinentry.pin, password, len);
+	  pinentry.pin[len] = '\0';
+
+	  secmem_free (password);
+
+	  pinentry.pin_from_cache = 1;
+
+	  assuan_write_status (ctx, "PASSWORD_FROM_CACHE", "");
+
+	  /* Result is the length of the password not including the
+	     NUL terminator.  */
+	  result = len - 1;
+
+	  just_read_password_from_cache = 1;
+
+	  goto out;
+	}
+    }
+
+  /* The password was not cached (or we are not allowed to / cannot
+     use the cache).  Prompt the user.  */
+  pinentry.pin_from_cache = 0;
+
   if (!pinentry.prompt)
     {
       pinentry.prompt = pinentry.default_prompt?pinentry.default_prompt:"PIN:";
       set_prompt = 1;
     }
   pinentry.locale_err = 0;
+  pinentry.specific_err = 0;
   pinentry.close_button = 0;
   pinentry.repeat_okay = 0;
   pinentry.one_button = 0;
@@ -974,9 +1070,12 @@ cmd_getpin (ASSUAN_CONTEXT ctx, char *line)
 	  secmem_free (pinentry.pin);
 	  pinentry.pin = NULL;
 	}
+      if (pinentry.specific_err)
+        return pinentry.specific_err;
       return pinentry.locale_err? ASSUAN_Locale_Problem: ASSUAN_Canceled;
     }
 
+ out:
   if (result)
     {
       if (pinentry.repeat_okay)
@@ -984,6 +1083,15 @@ cmd_getpin (ASSUAN_CONTEXT ctx, char *line)
       result = assuan_send_data (ctx, pinentry.pin, result);
       if (!result)
 	result = assuan_send_data (ctx, NULL, 0);
+
+      if (/* GPG Agent says it's okay.  */
+	  pinentry.allow_external_password_cache && pinentry.keyinfo
+	  /* We didn't just read it from the cache.  */
+	  && ! just_read_password_from_cache
+	  /* And the user said it's okay.  */
+	  && pinentry.may_cache_password)
+	/* Cache the password.  */
+	password_cache_save (pinentry.keyinfo, pinentry.pin);
     }
 
   if (pinentry.pin)
@@ -1012,6 +1120,7 @@ cmd_confirm (ASSUAN_CONTEXT ctx, char *line)
   pinentry.quality_bar = 0;
   pinentry.close_button = 0;
   pinentry.locale_err = 0;
+  pinentry.specific_err = 0;
   pinentry.canceled = 0;
   result = (*pinentry_cmd_handler) (&pinentry);
   if (pinentry.error)
@@ -1024,7 +1133,8 @@ cmd_confirm (ASSUAN_CONTEXT ctx, char *line)
     assuan_write_status (ctx, "BUTTON_INFO", "close");
 
   return result ? 0
-                : (pinentry.locale_err? ASSUAN_Locale_Problem
+                : (pinentry.specific_err? pinentry.specific_err :
+                   pinentry.locale_err? ASSUAN_Locale_Problem
                                       : (pinentry.one_button
                                          ? 0
                                          : (pinentry.canceled
@@ -1042,6 +1152,7 @@ cmd_message (ASSUAN_CONTEXT ctx, char *line)
   pinentry.quality_bar = 0;
   pinentry.close_button = 0;
   pinentry.locale_err = 0;
+  pinentry.specific_err = 0;
   result = (*pinentry_cmd_handler) (&pinentry);
   if (pinentry.error)
     {
@@ -1053,7 +1164,8 @@ cmd_message (ASSUAN_CONTEXT ctx, char *line)
     assuan_write_status (ctx, "BUTTON_INFO", "close");
 
   return result ? 0
-                : (pinentry.locale_err? ASSUAN_Locale_Problem
+                : (pinentry.specific_err? pinentry.specific_err :
+                   pinentry.locale_err? ASSUAN_Locale_Problem
                                       : 0);
 }
 
@@ -1101,6 +1213,7 @@ register_commands (ASSUAN_CONTEXT ctx)
     {
       { "SETDESC",    0,  cmd_setdesc },
       { "SETPROMPT",  0,  cmd_setprompt },
+      { "SETKEYINFO", 0,  cmd_setkeyinfo },
       { "SETREPEAT",  0,  cmd_setrepeat },
       { "SETREPEATERROR",0, cmd_setrepeaterror },
       { "SETERROR",   0,  cmd_seterror },
