@@ -28,8 +28,6 @@
 #include <stdarg.h>
 #include <assert.h>
 
-#define JNLIB_NEED_LOG_LOGV /* We need log_logv. */
-
 #include "gpgsm.h"
 #include <gcrypt.h>
 #include <ksba.h>
@@ -121,7 +119,7 @@ do_list (int is_error, int listmode, estream_t fp, const char *format, ...)
     }
   else
     {
-      log_logv (is_error? JNLIB_LOG_ERROR: JNLIB_LOG_INFO, format, arg_ptr);
+      log_logv (is_error? GPGRT_LOG_ERROR: GPGRT_LOG_INFO, format, arg_ptr);
       log_printf ("\n");
     }
   va_end (arg_ptr);
